@@ -1,4 +1,4 @@
-from __future__ import with_statement
+from __future__ import absolute_import, print_function, division
 
 import unittest
 from pony.orm.tests.testutils import raises_exception
