@@ -3,9 +3,10 @@ from __future__ import absolute_import, print_function, division
 import unittest
 from datetime import date, datetime
 from decimal import Decimal
+
 from pony.orm.core import *
 from pony.orm.sqltranslation import IncomparableTypesError
-from testutils import *
+from pony.orm.tests.testutils import *
 
 db = Database('sqlite', ':memory:')
 
