@@ -1,4 +1,4 @@
-from __future__ import with_statement
+from __future__ import absolute_import, print_function, division
 
 import unittest
 from pony.orm.core import *
@@ -81,7 +81,7 @@ class TestSymmetric(unittest.TestCase):
         self.assertEqual(p2_friends, set())
         try:
             p1_friends = set(p1.friends)
-        except UnrepeatableReadError, e:
+        except UnrepeatableReadError as e:
             self.assertEqual(e.args[0], "Phantom object Person[1] appeared in collection Person[2].friends")
         else: self.assert_(False)
     def test3b(self):
@@ -93,7 +93,7 @@ class TestSymmetric(unittest.TestCase):
         self.assertEqual(p1_friends, set([p2]))
         try:
             p2_friends = set(p2.friends)
-        except UnrepeatableReadError, e:
+        except UnrepeatableReadError as e:
             self.assertEqual(e.args[0], "Phantom object Person[1] disappeared from collection Person[2].friends")
         else: self.assert_(False)
 
